==> pcrm_book-1.0.tar.gz: pcrm_book-1.0/README.md <==
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/fortitudo-tech/pcrm-book/HEAD?urlpath=%2Fdoc%2Ftree%2F%2Fcode)

# Portfolio Construction and Risk Management book's Python code
This repository contains the accompanying code to Portfolio Construction and Risk
Management book © 2025 by Anton Vorobets. [You can find the latest PDF version of
the book in this Substack post](https://antonvorobets.substack.com/p/pcrm-book).

For a quick video introduction to what you can expect from this book and some
fundamental perspectives, [watch this video](https://antonvorobets.substack.com/p/anton-vorobets-next-generation-investment-framework).

Subscribe to the [Quantamental Investing Substack publication](https://antonvorobets.substack.com)
to stay updated on all news related to the book.

You can still support this project and potentially get perks and recognition for it,
see the [crowdfunding campaign](https://igg.me/at/pcrm-book).

For smaller contributions, please use [buy me a coffee](https://buymeacoffee.com/antonvorobets).

# Running the code
It is recommended to install the book's code dependencies in a 
[conda environment](https://conda.io/projects/conda/en/latest/user-guide/concepts/environments.html).

After cloning the repository to your local machine, you can install the dependencies
using the following command in your terminal:

    conda env create -f environment.yml

You can then activate the conda environment and start a [JupyterLab](https://jupyter.org/)
instance using the following commands:

    conda activate pcrm-book
    jupyter lab

If you are completely new to [conda environments](https://conda.io/projects/conda/en/latest/user-guide/tasks/manage-environments.html)
and Jupyter notebooks, you can find a lot of information online.

You can also run the code without any local installations using [Binder](https://mybinder.org/v2/gh/fortitudo-tech/pcrm-book/HEAD?urlpath=%2Fdoc%2Ftree%2F%2Fcode).
Note however that Binder servers are not always available and might have
insufficient resources to run all the examples.

# Feedback
Please post your feedback in the community Discussions forum. I will try to
incorporate the feedback in the book. See the book's preface for some general
perspectives on what it tries to achieve, and which kind feedback will
be considered appropriate.

# Thank you for your support
Your support made it possible for this book to be written.

Besides your personal monetary support, you can help improve the quality of the
book by simply publicly sharing your positive experience with the book and its code,
thereby encouraging more people to support the project. You
are also encouraged to give this and the supporting
[fortitudo.tech](https://github.com/fortitudo-tech/fortitudo.tech)
repository a star.

No matter how much economic support this project realistically gets, it will only
be a small fraction of the opportunity costs from writing the book and making it
freely available online. Hence, you are encouraged to support it by the amount that
you think it is worth to you.

[If you claim one of the significiant contributor perks](https://igg.me/at/pcrm-book),
you can choose to be recognized in the book's preface. You will additionally get a one-year
paid complimentary Substack subscription to the [Quantamental Investing publication](https://antonvorobets.substack.com),
which will contain exclusive case studies and allow you to continue asking questions.

# Licenses
The Portfolio Construction and Risk Management book © 2025 by Anton Vorobets is licensed
under Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 International. To view
a copy of this license, visit https://creativecommons.org/licenses/by-nc-nd/4.0/

The accompanying code to the Portfolio Construction and Risk Management book © 2025 by
Anton Vorobets is licensed under version 3 of the GNU General Public License. To view
a copy of this license, visit https://www.gnu.org/licenses/gpl-3.0.en.html

==> pcrm_book-1.0.3.tar.gz: pcrm_book-1.0.3/README.md <==
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/fortitudo-tech/pcrm-book/HEAD?urlpath=%2Fdoc%2Ftree%2F%2Fcode)

# Portfolio Construction and Risk Management book's Python code
This repository contains the accompanying code to Portfolio Construction and Risk
Management book © 2025 by Anton Vorobets.

[You can find the latest PDF version of the book in this Substack post](https://antonvorobets.substack.com/p/pcrm-book).

For a quick video introduction to what you can expect from this book and some
fundamental perspectives, [watch this video](https://antonvorobets.substack.com/p/anton-vorobets-next-generation-investment-framework).

Subscribe to the [Quantamental Investing Substack publication](https://antonvorobets.substack.com)
to stay updated on all news related to the book.

You can still support the project through [buy me a coffee](https://buymeacoffee.com/antonvorobets)
or [Substack](https://antonvorobets.substack.com).

# Applied Quantitative Investment Management course
You can access [a course that carefully goes through the book and its accompanying
code](https://antonvorobets.substack.com/t/course) from this repository.

[Read more about the course and how you get access here](https://antonvorobets.substack.com/p/course-q-and-a).

# Running the code
It is recommended to install the book's code dependencies in a 
[conda environment](https://conda.io/projects/conda/en/latest/user-guide/concepts/environments.html).

After cloning the repository to your local machine, you can install the dependencies
using the following command in your terminal:

    conda env create -f environment.yml

You can then activate the conda environment and start a [JupyterLab](https://jupyter.org/)
instance using the following commands:

    conda activate pcrm-book
    jupyter lab

If you are completely new to [conda environments](https://conda.io/projects/conda/en/latest/user-guide/tasks/manage-environments.html)
and Jupyter notebooks, you can find a lot of information online.

You can also run the code without any local installations using [Binder](https://mybinder.org/v2/gh/fortitudo-tech/pcrm-book/HEAD?urlpath=%2Fdoc%2Ftree%2F%2Fcode).
Note however that Binder servers are not always available and might have
insufficient resources to run all the examples.

# Feedback
Please post your feedback in the community Discussions forum. I will try to
incorporate the feedback in the book. See the book's preface for some general
perspectives on what it tries to achieve, and which kind feedback will
be considered appropriate.

# Thank you for your support
Your support made it possible for this book to be written.

Besides your personal monetary support, you can help improve the quality of the
book by simply publicly sharing your positive experience with the book and its code,
thereby encouraging more people to support the project. You
are also encouraged to give this and the supporting
[fortitudo.tech](https://github.com/fortitudo-tech/fortitudo.tech)
repository a star.

No matter how much economic support this project realistically gets, it will only
be a small fraction of the opportunity costs from writing the book and making it
freely available online. Hence, you are encouraged to support it by the amount that
you think it is worth to you.

[If you claim one of the significiant contributor perks](https://igg.me/at/pcrm-book),
you can choose to be recognized in the book's preface. You will additionally get a one-year
paid complimentary Substack subscription to the [Quantamental Investing publication](https://antonvorobets.substack.com),
which contains exclusive case studies and allow you to continue asking questions.

# Licenses
The Portfolio Construction and Risk Management book © 2025 by Anton Vorobets is licensed
under Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 International. To view
a copy of this license, visit https://creativecommons.org/licenses/by-nc-nd/4.0/

The accompanying code to the Portfolio Construction and Risk Management book © 2025 by
Anton Vorobets is licensed under version 3 of the GNU General Public License. To view
a copy of this license, visit https://www.gnu.org/licenses/gpl-3.0.en.html
